==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/mk.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Приватност",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Центарот за приватност ви покажува каде се складираат вашите податоци и кој има пристап до нив, или затоа што сте ги споделиле со некој или затоа што тие се администратори.",
    "Add external admin" : "Додади надворешен администратор",
    "Your files are not protected by encryption." : "Вашите датотеки не се заштитено со енкрипција.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Вашите датотеки се енкриптирани со {linkopen}енкрипција од страна на серверот ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Овој сервер е заштитен со целосно енкриптиран диск.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Вашите датотеки се енкриптирани со {linkopen}енкрипција од страна на серверот ↗{linkclose}. Дополнително, овој сервер е заштитен со целосно енкриптиран диск.",
    "This server is using full-disk-encryption." : "Овој сервер користи целосно енкриптиран диск.",
    "Your data is located in: " : "Вашите податоци се лоцирани во:",
    "The admin hasn't selected the location of the server yet." : "Администраторот сеуште нема избрано локација на серверот.",
    "Please select a country" : "Изберете држава",
    "You don't have any shares with individual users." : "Вие не споделувате податоци со индивидуални корисници.",
    "Somaliland" : "Somaliland",
    "United Arab Emirates" : "United Arab Emirates",
    "Afghanistan" : "Afghanistan",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegowina" : "Bosnia and Herzegowina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgium",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Democratic Republic of the Congo" : "Democratic Republic of the Congo",
    "Central African Republic" : "Central African Republic",
    "Congo" : "Congo",
    "Switzerland" : "Switzerland",
    "Cote d'Ivoire" : "Cote d'Ivoire",
    "Chile" : "Chile",
    "Cameroon" : "Cameroon",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Cyprus",
    "Czech" : "Czech",
    "Germany" : "Germany",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominican Republic" : "Dominican Republic",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egypt",
    "West Sahara" : "West Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spain",
    "Ethiopia" : "Ethiopia",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falkland Islands",
    "France" : "France",
    "Gabon" : "Gabon",
    "United Kingdom" : "United Kingdom",
    "Georgia" : "Georgia",
    "Ghana" : "Ghana",
    "Greenland" : "Greenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Greece",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Croatia" : "Croatia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungary",
    "Indonesia" : "Indonesia",
    "Ireland" : "Ireland",
    "Israel" : "Israel",
    "India" : "India",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Iceland",
    "Italy" : "Italy",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Cambodia",
    "North Korea" : "North Korea",
    "South Korea" : "South Korea",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Kazakhstan",
    "Laos" : "Laos",
    "Lebanon" : "Lebanon",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lithuania",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Morocco",
    "Moldova" : "Moldova",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Mauritania" : "Mauritania",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Netherlands",
    "Norway" : "Norway",
    "Nepal" : "Nepal",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua New Guinea",
    "Philippines" : "Philippines",
    "Pakistan" : "Pakistan",
    "Poland" : "Poland",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russia" : "Russia",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Solomon Islands",
    "Sudan" : "Sudan",
    "Sweden" : "Sweden",
    "Singapore" : "Singapore",
    "Slovenia" : "Slovenia",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "South Sudan",
    "El Salvador" : "El Salvador",
    "Syria" : "Syria",
    "Swaziland" : "Swaziland",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Fr. S. Antarctic Lands",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Turkey" : "Turkey",
    "Trinidad and Tobago" : "Trinidad and Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States" : "United States",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Yemen",
    "South Africa" : "South Africa",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Вашата сметка",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Вашите податоци ве претставуваат вас и лесно можат да бидат злоупотребени. Ние во Nextcloud веруваме дека имате право да одлучите што ќе случува со вашите податоци. Nextcloud ги штити вашите права како што е дефинирано во Манифестот за кориснички податоци!",
    "User Data Manifesto 2.0" : "Манифест за кориснички податоци 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Дефинирање на основните права за луѓето да ги контролираат своите податоци во ерата на Интернет",
    "Control" : "Контрола",
    "over user data access" : "на пристап до податоци од корисници",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Податоците експлицитно и доброволно поставени од корисникот треба да бидат под неограничена контрола на корисникот. Корисниците треба сами да одлучат кому да му дадат директен пристап до нивните податоци и со какви дозволи и лиценци треба да им се овозможи пристап.",
    "Knowledge" : "Знаење",
    "of how the data is stored" : "за тоа како се чуваат податоци",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Кога податоците се поставуваат на одреден давател на услуги, корисниците треба да бидат информирани за тоа каде тој конкретен давател на услуга чува податоци, колку долго, во која надлежност работи специфичниот давател на услуги и кој закони се применуваат.",
    "Freedom" : "Слобода",
    "to choose a platform" : "за избор на платформа",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Корисниците треба секогаш да бидат во можност да ги повлечат своите податоци во кое било време, без да искусат заклучување на добавувачот. Отворени стандарди за формати и протоколи се неопходни за да се гарантира ова.",
    "Learn more ↗" : "Научи повеќе ↗",
    "Where is your data?" : "Каде се вашите податоци?",
    "Who has access to your data?" : "Кој има пристап до вашите податоци?",
    "Administrators" : "Администратори",
    "People you shared with" : "Луѓе со кој споделувате податоци",
    "Privacy policy" : "Политика за приватност",
    "Read the privacy policy." : "Прочитај ја политиката за приватност",
    "Encryption" : "Енкрипција"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/mk.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Приватност",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Центарот за приватност ви покажува каде се складираат вашите податоци и кој има пристап до нив, или затоа што сте ги споделиле со некој или затоа што тие се администратори.",
    "Add external admin" : "Додади надворешен администратор",
    "Your files are not protected by encryption." : "Вашите датотеки не се заштитени со енкрипција.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Вашите датотеки се енкриптирани со {linkopen}енкрипција од страна на серверот ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Овој сервер е заштитен со целосно енкриптиран диск.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Вашите датотеки се енкриптирани со {linkopen}енкрипција од страна на серверот ↗{linkclose}. Дополнително, овој сервер е заштитен со целосно енкриптиран диск.",
    "This server is using full-disk-encryption." : "Овој сервер користи целосно енкриптиран диск.",
    "Your data is located in: " : "Вашите податоци се лоцирани во:",
    "The admin hasn't selected the location of the server yet." : "Администраторот сеуште нема избрано локација на серверот.",
    "Please select a country" : "Изберете држава",
    "You don't have any shares with individual users." : "Вие не споделувате податоци со индивидуални корисници.",
    "Somaliland" : "Somaliland",
    "United Arab Emirates" : "United Arab Emirates",
    "Afghanistan" : "Afghanistan",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegowina" : "Bosnia and Herzegowina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgium",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Democratic Republic of the Congo" : "Democratic Republic of the Congo",
    "Central African Republic" : "Central African Republic",
    "Congo" : "Congo",
    "Switzerland" : "Switzerland",
    "Cote d'Ivoire" : "Cote d'Ivoire",
    "Chile" : "Chile",
    "Cameroon" : "Cameroon",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Cyprus",
    "Czech" : "Czech",
    "Germany" : "Germany",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominican Republic" : "Dominican Republic",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egypt",
    "West Sahara" : "West Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spain",
    "Ethiopia" : "Ethiopia",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falkland Islands",
    "France" : "France",
    "Gabon" : "Gabon",
    "United Kingdom" : "United Kingdom",
    "Georgia" : "Georgia",
    "Ghana" : "Ghana",
    "Greenland" : "Greenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Greece",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Croatia" : "Croatia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungary",
    "Indonesia" : "Indonesia",
    "Ireland" : "Ireland",
    "Israel" : "Israel",
    "India" : "India",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Iceland",
    "Italy" : "Italy",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Cambodia",
    "North Korea" : "North Korea",
    "South Korea" : "South Korea",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Kazakhstan",
    "Laos" : "Laos",
    "Lebanon" : "Lebanon",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lithuania",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Morocco",
    "Moldova" : "Moldova",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Mauritania" : "Mauritania",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Netherlands",
    "Norway" : "Norway",
    "Nepal" : "Nepal",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua New Guinea",
    "Philippines" : "Philippines",
    "Pakistan" : "Pakistan",
    "Poland" : "Poland",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russia" : "Russia",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Solomon Islands",
    "Sudan" : "Sudan",
    "Sweden" : "Sweden",
    "Singapore" : "Singapore",
    "Slovenia" : "Slovenia",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "South Sudan",
    "El Salvador" : "El Salvador",
    "Syria" : "Syria",
    "Swaziland" : "Swaziland",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Fr. S. Antarctic Lands",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Turkey" : "Turkey",
    "Trinidad and Tobago" : "Trinidad and Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States" : "United States",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Yemen",
    "South Africa" : "South Africa",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Вашата сметка",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Вашите податоци ве претставуваат вас и лесно можат да бидат злоупотребени. Ние во Nextcloud веруваме дека имате право да одлучите што ќе случува со вашите податоци. Nextcloud ги штити вашите права како што е дефинирано во Манифестот за кориснички податоци!",
    "User Data Manifesto 2.0" : "Манифест за кориснички податоци 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Дефинирање на основните права за луѓето да ги контролираат своите податоци во ерата на Интернет",
    "Control" : "Контрола",
    "over user data access" : "на пристап до податоци од корисници",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Податоците експлицитно и доброволно поставени од корисникот треба да бидат под неограничена контрола на корисникот. Корисниците треба сами да одлучат кому да му дадат директен пристап до нивните податоци и со какви дозволи и лиценци треба да им се овозможи пристап.",
    "Knowledge" : "Знаење",
    "of how the data is stored" : "за тоа како се чуваат податоци",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Кога податоците се поставуваат на одреден давател на услуги, корисниците треба да бидат информирани за тоа каде тој конкретен давател на услуга чува податоци, колку долго, во која надлежност работи специфичниот давател на услуги и кој закони се применуваат.",
    "Freedom" : "Слобода",
    "to choose a platform" : "за избор на платформа",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Корисниците треба секогаш да бидат во можност да ги повлечат своите податоци во кое било време, без да искусат заклучување на добавувачот. Отворени стандарди за формати и протоколи се неопходни за да се гарантира ова.",
    "Learn more ↗" : "Научи повеќе ↗",
    "Where is your data?" : "Каде се вашите податоци?",
    "Who has access to your data?" : "Кој има пристап до вашите податоци?",
    "Administrators" : "Администратори",
    "People you shared with" : "Луѓе со кој споделувате податоци",
    "Privacy policy" : "Политика за приватност",
    "Read the privacy policy." : "Прочитај ја политиката за приватност",
    "Encryption" : "Енкрипција"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
